@@ -2,14 +2,8 @@ import pathlib
 
 from data_pipelines_cli.data_structures import DataPipelinesConfig
 
-#: DataHub URL environment variable to search for
-DATAHUB_URL_ENV: str = "DATAHUB_URL"
 #:
 IMAGE_TAG_TO_REPLACE: str = "<IMAGE_TAG>"
-#:
-DOCKER_REPOSITORY_URL_TO_REPLACE: str = "<DOCKER_REPOSITORY_URL>"
-#:
-INGEST_ENDPOINT_TO_REPLACE: str = "<INGEST_ENDPOINT>"
 #: Name of the environment and dbt target to use for a local machine
 PROFILE_NAME_LOCAL_ENVIRONMENT = "local"
 #: Name of the dbt target to use for a remote machine
@@ -30,7 +24,7 @@ BUILD_DIR: pathlib.Path = pathlib.Path.cwd().joinpath("build")
 def get_dbt_profiles_env_name(env: str) -> str:
     """
     Given a name of the environment, returns one of target names expected by
-    the `profiles.yml` file
+    the `profiles.yml` file.
 
     :param env: Name of the environment
     :type env: str
