@@ -50,6 +50,13 @@ class DeployCommandTestCase(unittest.TestCase):
         with open(self.dbt_project_config_dir.joinpath("dbt_project.yml"), "w") as f:
             yaml.dump(self.dbt_project_config, f)
 
+        self.build_temp_dir = pathlib.Path(tempfile.mkdtemp())
+        dags_path = pathlib.Path(self.build_temp_dir).joinpath("dag")
+        dags_path.mkdir(parents=True)
+        shutil.copytree(
+            self.goldens_dir_path.joinpath("config"), dags_path.joinpath("config")
+        )
+
         self.storage_uri = tempfile.mkdtemp()  # this way fsspec uses LocalFS
 
         self.subprocess_run_args = []
@@ -59,6 +66,7 @@ class DeployCommandTestCase(unittest.TestCase):
 
     def tearDown(self) -> None:
         shutil.rmtree(self.storage_uri)
+        shutil.rmtree(self.build_temp_dir)
         shutil.rmtree(self.dbt_project_config_dir)
         os.remove(self.blob_json_filename)
 
@@ -74,6 +82,7 @@ class DeployCommandTestCase(unittest.TestCase):
 
                 def mock_init(
                     _self,
+                    _env,
                     _docker_push,
                     _blob_address,
                     provider_kwargs_dict,
@@ -101,7 +110,7 @@ class DeployCommandTestCase(unittest.TestCase):
         # 'filesystem_utils.LocalRemoteSync' here. It gets tested in
         # a dedicated 'test_filesystem_utils' file.
         runner = CliRunner()
-        with patch("pathlib.Path.cwd", lambda _: self.dbt_project_config_dir):
+        with patch("pathlib.Path.cwd", lambda: self.dbt_project_config_dir):
             result = runner.invoke(
                 _cli,
                 [
@@ -121,12 +130,14 @@ class DeployCommandTestCase(unittest.TestCase):
     def test_no_module_cli(self):
         for module_name, cli_args in [
             ("datahub", ["--datahub-ingest"]),
-            ("docker", ["--docker-push", "rep"]),
+            ("docker", ["--docker-push"]),
         ]:
             with self.subTest(dep=module_name):
                 runner = CliRunner()
                 with patch.dict("sys.modules", **{module_name: None}), patch(
-                    "pathlib.Path.cwd", lambda _: self.dbt_project_config_dir
+                    "pathlib.Path.cwd", lambda: self.dbt_project_config_dir
+                ), patch(
+                    "data_pipelines_cli.cli_constants.BUILD_DIR", self.build_temp_dir
                 ):
                     result = runner.invoke(
                         _cli,
@@ -144,17 +155,21 @@ class DeployCommandTestCase(unittest.TestCase):
 
     def test_no_datahub_method(self):
         with patch.dict("sys.modules", datahub=None), patch(
-            "pathlib.Path.cwd", lambda _: self.dbt_project_config_dir
+            "pathlib.Path.cwd", lambda: self.dbt_project_config_dir
         ):
             with self.assertRaises(DependencyNotInstalledError):
-                DeployCommand(None, self.storage_uri, self.provider_args, True).deploy()
+                DeployCommand(
+                    "base", False, self.storage_uri, self.provider_args, True
+                ).deploy()
 
     @patch("data_pipelines_cli.cli_commands.deploy.BUILD_DIR", goldens_dir_path)
     def test_datahub_run(self):
-        with patch("pathlib.Path.cwd", lambda _: self.dbt_project_config_dir), patch(
+        with patch("pathlib.Path.cwd", lambda: self.dbt_project_config_dir), patch(
             "data_pipelines_cli.cli_commands.deploy.subprocess_run", self._mock_run
         ), patch.dict("sys.modules", datahub=MagicMock()):
-            DeployCommand(None, self.storage_uri, self.provider_args, True).deploy()
+            DeployCommand(
+                "base", False, self.storage_uri, self.provider_args, True
+            ).deploy()
             self.assertListEqual(
                 [
                     "datahub",
@@ -167,11 +182,11 @@ class DeployCommandTestCase(unittest.TestCase):
 
     def test_no_docker_method(self):
         with patch.dict("sys.modules", docker=None), patch(
-            "pathlib.Path.cwd", lambda _: self.dbt_project_config_dir
-        ):
+            "pathlib.Path.cwd", lambda: self.dbt_project_config_dir
+        ), patch("data_pipelines_cli.cli_constants.BUILD_DIR", self.build_temp_dir):
             with self.assertRaises(DependencyNotInstalledError):
                 DeployCommand(
-                    "rep", self.storage_uri, self.provider_args, False
+                    "base", True, self.storage_uri, self.provider_args, False
                 ).deploy()
 
     @patch(
@@ -180,7 +195,7 @@ class DeployCommandTestCase(unittest.TestCase):
     )
     def test_no_airflow_address(self):
         with self.assertRaises(AirflowDagsPathKeyError):
-            DeployCommand(None, None, None, False)
+            DeployCommand("base", False, None, None, False)
 
     def test_airflow_address(self):
         with tempfile.TemporaryDirectory() as tmp_dir, patch(
@@ -195,12 +210,34 @@ class DeployCommandTestCase(unittest.TestCase):
                 tmp_airflow_path,
             )
 
-            deploy_command = DeployCommand(None, None, None, False)
+            deploy_command = DeployCommand("base", False, None, None, False)
         self.assertEqual(
             "gcs://test-sync-project/sync-dir/dags/my-project-name",
             deploy_command.blob_address_path,
         )
 
+    def test_staging_airflow_address(self):
+        with tempfile.TemporaryDirectory() as tmp_dir, patch(
+            "data_pipelines_cli.cli_commands.deploy.BUILD_DIR", pathlib.Path(tmp_dir)
+        ), patch(
+            "data_pipelines_cli.config_generation.BUILD_DIR",
+            pathlib.Path(tmp_dir),
+        ):
+            for env in ["base", "staging"]:
+                tmp_config_path = pathlib.Path(tmp_dir).joinpath("dag", "config", env)
+                tmp_config_path.mkdir(parents=True, exist_ok=True)
+                tmp_file_path = tmp_config_path.joinpath("airflow.yml")
+                shutil.copyfile(
+                    self.goldens_dir_path.joinpath("config", env, "airflow.yml"),
+                    tmp_file_path,
+                )
+
+            deploy_command = DeployCommand("staging", False, None, None, False)
+        self.assertEqual(
+            "gcs://test/jinja/path/com/my/project/name",
+            deploy_command.blob_address_path,
+        )
+
     @patch("data_pipelines_cli.cli_commands.deploy.BUILD_DIR", goldens_dir_path)
     def test_docker_run(self):
         docker_kwargs = {}
@@ -218,13 +255,17 @@ class DeployCommandTestCase(unittest.TestCase):
         docker_mock.configure_mock(**{"from_env": lambda: docker_client_mock})
 
         with patch.dict("sys.modules", docker=docker_mock), patch(
-            "pathlib.Path.cwd", lambda _: self.dbt_project_config_dir
+            "pathlib.Path.cwd", lambda: self.dbt_project_config_dir
         ), patch("docker.from_env", lambda: docker_client_mock), patch(
             "data_pipelines_cli.data_structures.git_revision_hash", lambda: "sha1234"
+        ), patch(
+            "data_pipelines_cli.cli_constants.BUILD_DIR", self.build_temp_dir
         ):
-            DeployCommand("rep", self.storage_uri, self.provider_args, False).deploy()
+            DeployCommand(
+                "base", True, self.storage_uri, self.provider_args, False
+            ).deploy()
 
-        self.assertEqual("rep", docker_kwargs.get("repository"))
+        self.assertEqual("my_docker_repository_uri", docker_kwargs.get("repository"))
         self.assertEqual("sha1234", docker_kwargs.get("tag"))
 
     @patch("data_pipelines_cli.cli_commands.deploy.BUILD_DIR", goldens_dir_path)
@@ -244,13 +285,14 @@ class DeployCommandTestCase(unittest.TestCase):
         docker_mock = MagicMock()
         docker_mock.configure_mock(**{"from_env": lambda: docker_client_mock})
 
-        with patch(
-            "pathlib.Path.cwd", lambda _: self.dbt_project_config_dir
-        ), patch.dict("sys.modules", docker=docker_mock), patch(
+        with patch("pathlib.Path.cwd", lambda: self.dbt_project_config_dir), patch.dict(
+            "sys.modules", docker=docker_mock
+        ), patch(
             "data_pipelines_cli.data_structures.git_revision_hash", lambda: "sha1234"
+        ), patch(
+            "data_pipelines_cli.cli_constants.BUILD_DIR", self.build_temp_dir
         ):
-
             with self.assertRaises(DataPipelinesError):
                 DeployCommand(
-                    "rep", self.storage_uri, self.provider_args, False
+                    "base", True, self.storage_uri, self.provider_args, False
                 ).deploy()
